@@ -2,6 +2,8 @@
 #'
 #' This function specifies the default logos that are displayed in the "Admin Panel".
 #'
+#' @importFrom htmltools tagList tags
+#'
 #' @return the default list of HTML for branding elements in the Admin Panel UI. The valid list element names are:
 #' \itemize{
 #'   \item \code{title} - Title/Logo element in top left corner of Admin Panel dashboard & browser tab title
@@ -13,11 +15,12 @@ default_admin_ui_options <- function() {
   list(
 
 
-    title = tagList(
-      tags$a(
+    title = htmltools::tagList(
+      htmltools::tags$a(
         href = "https://polished.tech/",
-        tags$img(
-          src="polish/images/polished_logo_transparent_text_2.png",
+        target = "_blank",
+        htmltools::tags$img(
+          src = "polish/images/polished_logo_transparent_text_2.png",
           style = "height: 37.5px; width: 180px; padding: 0",
           alt = "Polished Logo"
         )
@@ -26,15 +29,16 @@ default_admin_ui_options <- function() {
     ),
 
 
-    sidebar_branding = tags$a(
+    sidebar_branding = htmltools::tags$a(
       href = "https://www.tychobra.com/",
-      tags$img(
+      target = "_blank",
+      htmltools::tags$img(
         style = "position: fixed; bottom: 0; left: 0; width: 230px;",
         src = "polish/images/tychobra_logo_blue_co_name.png"
       )
     ),
 
-    browser_tab_icon = tags$link(
+    browser_tab_icon = htmltools::tags$link(
       rel = "shortcut icon",
       href = "polish/images/polished_icon.png"
     )
