@@ -1,7 +1,9 @@
 
-the_config <- config::get()
+if (file.exists("config.yml")) {
+  the_config <- config::get()
 
-polished::set_api_key(the_config$api_key)
+  polished::set_api_key(the_config$api_key)
+}
 
 #polished:::set_api_url(
 #  api_url = "http://0.0.0.0:8080/v1",
